@@ -1,7 +1,3 @@
-import os
-
-LIBRARY_ROOT = os.path.dirname(os.path.abspath(__file__))
-
 ALMS_USER = None
 LABS_USER = None
 
